<!doctype html>
<html>
    <head>
        <title>Test</title>
    </head>
    <body>
        <h1>Test</h1>
        <form action="." method="POST">
            {{ form.as_p }}
            {% csrf_token %}
            <input type="submit" value="Test" />
        </form>
    </body>
</html>
